@@ -168,5 +168,5 @@ class NavParser:
         return max(self._points, key=lambda s: self._points[s].get_satellites_count())
 
     def get_most_recent_points(self, num_of_points=1):
-        coords = sorted(self._points, key=lambda s: self._points[s].get_timestamp())[:num_of_points]
+        coords = sorted(self._points, key=lambda s: self._points[s].get_timestamp(), reverse=True)[:num_of_points]
         return [self._points[c] for c in coords]
